@@ -1,7 +1,6 @@
 
 using System;
 using System.IO;
-using System.Collections;
 using System.Collections.Generic;
 using Mono.Unix;
 
@@ -176,7 +175,8 @@ public NoteManager (string directory) :
 				                          links_note_content);
 				links_note.QueueSave (ChangeType.ContentChanged);
 
-				start_note.Window.Show ();
+				if (!Tomboy.IsPanelApplet)
+					start_note.Window.Show ();
 			} catch (Exception e) {
 				Logger.Warn ("Error creating start notes: {0}\n{1}",
 				             e.Message, e.StackTrace);
@@ -377,7 +377,8 @@ public NoteManager (string directory) :
 			if (note_template != null) {
 				// Use the body from the "New Note Template" note
 				string xml_content =
-					note_template.XmlContent.Replace (NoteTemplateTitle, title);
+					note_template.XmlContent.Replace (NoteTemplateTitle,
+					                                  XmlEncoder.Encode (title));
 				return CreateNewNote (title, xml_content, guid);
 			}
 			
